pub struct CircleCurve { /* private fields */ }Expand description
A circle, parameterized by angle.
Implementations
Sourceimpl CircleCurve
impl CircleCurve
Sourcepub const fn new(circle: Circle) -> Self
pub const fn new(circle: Circle) -> Self
A full circle, running counter-clockwise about its frame’s z.
Sourcepub const fn is_reversed(&self) -> bool
pub const fn is_reversed(&self) -> bool
Whether the curve runs backwards along its underlying circle.
Part of the curve’s state and not derivable from its circle, so anything that has to reproduce this curve exactly (the native format above all) needs to be able to read it.