EllipseCurve

Struct EllipseCurve 

pub struct EllipseCurve { /* private fields */ }
An ellipse, parameterized by eccentric angle.

Implementations

Source

impl EllipseCurve

pub const fn new(ellipse: Ellipse) -> Self

A full ellipse.

pub const fn ellipse(&self) -> Ellipse

The underlying ellipse.

pub const fn is_reversed(&self) -> bool

Whether the curve runs backwards along its underlying ellipse.

Part of the curve’s state and not derivable from its ellipse, so anything that has to reproduce this curve exactly (the native format above all) needs to be able to read it.