pub struct HyperbolaCurve { /* private fields */ }Expand description
One branch of a hyperbola.
Implementations
Sourceimpl HyperbolaCurve
impl HyperbolaCurve
Sourcepub fn new(hyperbola: Hyperbola, extent: f64) -> OgeomResult<Self>
pub fn new(hyperbola: Hyperbola, extent: f64) -> OgeomResult<Self>
A hyperbola branch over [-extent, extent] in its natural parameter.
Errors
OgeomError::Construction if extent is
not finite and positive.
Sourcepub fn over(hyperbola: Hyperbola, start: f64, end: f64) -> OgeomResult<Self>
pub fn over(hyperbola: Hyperbola, start: f64, end: f64) -> OgeomResult<Self>
A hyperbola branch over an arbitrary [start, end] in its natural
parameter.
Errors
OgeomError::Construction if the
interval is not finite and increasing.
Sourcepub const fn is_reversed(&self) -> bool
pub const fn is_reversed(&self) -> bool
Whether the curve runs backwards along its underlying hyperbola.
Part of the curve’s state and not derivable from its hyperbola, so anything that has to reproduce this curve exactly (the native format above all) needs to be able to read it.