ParabolaCurve

Struct ParabolaCurve 

pub struct ParabolaCurve { /* private fields */ }
A parabola.

Implementations

Source

impl ParabolaCurve

pub fn new(parabola: Parabola, extent: f64) -> OgeomResult<Self>

A parabola over [-extent, extent].

Errors

OgeomError::Construction if extent is not finite and positive.

pub fn over(parabola: Parabola, start: f64, end: f64) -> OgeomResult<Self>

A parabola over an arbitrary [start, end].

Errors

OgeomError::Construction if the interval is not finite and increasing.

pub const fn parabola(&self) -> Parabola

The underlying parabola.

pub const fn is_reversed(&self) -> bool

Whether the curve runs backwards along its underlying parabola.

Part of the curve’s state and not derivable from its parabola, so anything that has to reproduce this curve exactly (the native format above all) needs to be able to read it.