Circle2d

Struct Circle2d 

pub struct Circle2d { /* private fields */ }
A circle in the plane, parameterized by angle.

Implementations

Source

impl Circle2d

pub const fn new(circle: Circle2) -> Self

A full circle.

pub const fn circle(&self) -> Circle2

The underlying circle.

pub const fn is_reversed(&self) -> bool

Whether the curve runs backwards along its underlying circle.

Part of the curve’s state and not derivable from its circle, so anything that has to reproduce this curve exactly (the native format above all) needs to be able to read it.