pub struct Line2d { /* private fields */ }Expand description
A straight line in the plane, parameterized by length.
Implementations
Sourceimpl Line2d
impl Line2d
Sourcepub fn segment(from: Point2, to: Point2, tol: Tolerances) -> OgeomResult<Self>
pub fn segment(from: Point2, to: Point2, tol: Tolerances) -> OgeomResult<Self>
A segment between two distinct points, parameterized by arc length.
Errors
OgeomError::Construction if the points
coincide.