pub struct Trimmed2d { /* private fields */ }Expand description
Another planar curve restricted to a sub-interval.
Implementations
Sourceimpl Trimmed2d
impl Trimmed2d
Sourcepub fn new(
basis: PlanarCurve,
start: f64,
end: f64,
tol: Tolerances,
) -> OgeomResult<Self>
pub fn new( basis: PlanarCurve, start: f64, end: f64, tol: Tolerances, ) -> OgeomResult<Self>
Restrict basis to [start, end].
Errors
OgeomError::Domain if the range is empty or
leaves the basis curve’s domain.
Sourcepub const fn basis(&self) -> &PlanarCurve
pub const fn basis(&self) -> &PlanarCurve
The curve being trimmed.
Sourcepub const fn is_reversed(&self) -> bool
pub const fn is_reversed(&self) -> bool
Whether the curve runs backwards along its underlying curve.
Part of the curve’s state and not derivable from its basis curve, so anything that has to reproduce this curve exactly (the native format above all) needs to be able to read it.