fit_surface_grid_chordal

Function fit_surface_grid_chordal 

pub fn fit_surface_grid_chordal(
    rows: &[Vec<Point>],
    degree: usize,
    tolerance: f64,
    tol: Tolerances,
) -> OgeomResult<Fitted<BSplineSurface>>
As fit_surface_grid, parameterized by chord length instead of the centripetal assignment, the open counterpart of fit_surface_grid_closed_v_chordal, for a marched band that stops at its run-out instead of closing on itself.

Errors

As fit_surface_grid.