#[non_exhaustive]pub enum CurveKind {
Line,
Circle,
Ellipse,
Hyperbola,
Parabola,
Bezier,
BSpline,
Helix,
Trimmed,
Offset,
OnSurface,
Trig,
}Expand description
What kind of curve this is, for analytic fast paths.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Line
A straight line.
Circle
A circle or circular arc.
Ellipse
An ellipse or elliptical arc.
Hyperbola
One branch of a hyperbola.
Parabola
A parabola.
Bezier
A polynomial or rational Bézier.
BSpline
A polynomial or rational B-spline.
Helix
A helix about an axis.
Trimmed
A restriction of another curve to a sub-interval.
Offset
A curve offset from another.
OnSurface
A pcurve composed with the surface it is drawn on.
Trig
An affine-plus-trigonometric chart curve.