pub struct EllipseCurve { /* private fields */ }Expand description
An ellipse, parameterized by eccentric angle.
Implementations
Sourceimpl EllipseCurve
impl EllipseCurve
Sourcepub const fn is_reversed(&self) -> bool
pub const fn is_reversed(&self) -> bool
Whether the curve runs backwards along its underlying ellipse.
Part of the curve’s state and not derivable from its ellipse, so anything that has to reproduce this curve exactly (the native format above all) needs to be able to read it.